@@ -4,6 +4,9 @@
 //! - Supported elements are inclusion, local variable, and functions
 //!
 
+extern crate chrono;
+extern crate regex;
+
 use chrono::Utc;
 use regex::Regex;
 
@@ -82,9 +85,9 @@ impl Parser {
 /// - **@ncls@** or **@ncls-once@** : the list of nested calls, no duplicate callee with **ncls-once**
 ///     - **@callee.name@** : the function name of callee
 ///     - **@callee.rtype@** : the return type of callee
-///     - **@callee.rtype.change(<from>=<to>)@** : to change return data type during generation
-///     - **@callee.rtype.variable(<var>)@** : <var> string to be removed when `void`
-///     - **@callee.rtype.value(<val>)@** : <val> string to be removed when `void`
+///     - **@callee.rtype.change(\<from\>=\<to\>)@** : to change return data type during generation
+///     - **@callee.rtype.variable(\<var\>)@** : \<var\> string to be removed when `void`
+///     - **@callee.rtype.value(\<val\>)@** : \<val\> string to be removed when `void`
 ///     - **@callee.args@** : the argument list string
 ///     - **@callee.atypes@** : only arguments' data types
 ///     - **@caller.name@** : the function name of caller
@@ -330,7 +333,7 @@ fn get_local_vars<'a>(code: &'a str) -> Vec<LocalVariable> {
 fn get_fncs<'a>(code: &'a str) -> Vec<Function> {
     let mut result = vec![];
     let re = Regex::new(
-        r"[\n][\s\t]*(?P<return_func>([a-zA-Z_][a-zA-Z_0-9]*\s+)+([a-zA-Z_][a-zA-Z_0-9]*\s*))\((?P<args>[^=!><>;\(\)-]*)\)[\s\t\r\n]*\{",
+        r"[\n]*[\s\t]*(?P<return_func>([a-zA-Z_][a-zA-Z_0-9]*\s+)+([a-zA-Z_][a-zA-Z_0-9]*\s*))\((?P<args>[^=!><>;\(\)-]*)\)[\s\t\r\n]*\{",
     ).unwrap();
     let get_types = |args: &'a str| -> String {
         let mut type_list = String::new();
